import Joi from "joi";

export const isValidationError = (
  error: unknown
): error is Joi.ValidationError => error instanceof Joi.ValidationError;

export const isValue = <T>(value: T | Array<T> | undefined): value is T =>
  !!value && !Array.isArray(value);

export const isSize = (value: unknown): value is string =>
  !Array.isArray(value) &&
  !isNaN(parseInt(value as string)) &&
  parseInt(value as string) <= 512 &&
  parseInt(value as string) >= 16;

export const isStyle =
  (validStyles: string[]) =>
  <T>(value: T | Array<T> | undefined): value is T =>
    !!value && !Array.isArray(value) && validStyles.includes(value as string);
